@@ -923,9 +923,15 @@ class Env(object):
 
     def __init__(self, path, base=None):  # type: (Path, Optional[Path]) -> None
         self._is_windows = sys.platform == "win32"
+        self._is_mingw = sysconfig.get_platform().startswith("mingw")
+        self._is_conda = bool(os.environ.get("CONDA_DEFAULT_ENV"))
+
+        if not self._is_windows or self._is_mingw:
+            bin_dir = "bin"
+        else:
+            bin_dir = "Scripts"
 
         self._path = path
-        bin_dir = "bin" if not self._is_windows else "Scripts"
         self._bin_dir = self._path / bin_dir
 
         self._base = base or path
@@ -1075,13 +1081,16 @@ class Env(object):
 
         return sys.prefix
 
-    def find_executables(self):  # type: () -> None
+    def _find_python_executable(self):  # type: () -> None
+        bin_dir = self._bin_dir
+
+        if self._is_windows and self._is_conda:
+            bin_dir = self._path
+
         python_executables = sorted(
-            [
-                p.name
-                for p in self._bin_dir.glob("python*")
-                if re.match(r"python(?:\d+(?:\.\d+)?)?(?:\.exe)?$", p.name)
-            ]
+            p.name
+            for p in bin_dir.glob("python*")
+            if re.match(r"python(?:\d+(?:\.\d+)?)?(?:\.exe)?$", p.name)
         )
         if python_executables:
             executable = python_executables[0]
@@ -1090,12 +1099,11 @@ class Env(object):
 
             self._executable = executable
 
+    def _find_pip_executable(self):  # type: () -> None
         pip_executables = sorted(
-            [
-                p.name
-                for p in self._bin_dir.glob("pip*")
-                if re.match(r"pip(?:\d+(?:\.\d+)?)?(?:\.exe)?$", p.name)
-            ]
+            p.name
+            for p in self._bin_dir.glob("pip*")
+            if re.match(r"pip(?:\d+(?:\.\d+)?)?(?:\.exe)?$", p.name)
         )
         if pip_executables:
             pip_executable = pip_executables[0]
@@ -1104,6 +1112,10 @@ class Env(object):
 
             self._pip_executable = pip_executable
 
+    def find_executables(self):  # type: () -> None
+        self._find_python_executable()
+        self._find_pip_executable()
+
     def get_version_info(self):  # type: () -> Tuple[int]
         raise NotImplementedError()
 
@@ -1147,6 +1159,9 @@ class Env(object):
         cmd = pip + list(args)
         return self._run(cmd, **kwargs)
 
+    def run_python_script(self, content, **kwargs):  # type: (str, Any) -> str
+        return self.run(self._executable, "-W", "ignore", "-", input_=content, **kwargs)
+
     def _run(self, cmd, **kwargs):
         """
         Run a command inside the Python environment.
@@ -1228,7 +1243,7 @@ class Env(object):
             # a base Python install.
             if self._is_windows:
                 if not bin.endswith(".exe"):
-                    bin_path = self._bin_dir / (bin + ".exe")
+                    bin_path = self._path / (bin + ".exe")
                 else:
                     bin_path = self._path / bin
 
@@ -1357,18 +1372,16 @@ class VirtualEnv(Env):
         # In this case we need to get sys.base_prefix
         # from inside the virtualenv.
         if base is None:
-            self._base = Path(
-                self.run(self._executable, "-", input_=GET_BASE_PREFIX).strip()
-            )
+            self._base = Path(self.run_python_script(GET_BASE_PREFIX).strip())
 
     @property
     def sys_path(self):  # type: () -> List[str]
-        output = self.run(self._executable, "-", input_=GET_SYS_PATH)
+        output = self.run_python_script(GET_SYS_PATH)
 
         return json.loads(output)
 
     def get_version_info(self):  # type: () -> Tuple[int]
-        output = self.run(self._executable, "-", input_=GET_PYTHON_VERSION)
+        output = self.run_python_script(GET_PYTHON_VERSION)
 
         return tuple([int(s) for s in output.strip().split(".")])
 
@@ -1406,7 +1419,7 @@ class VirtualEnv(Env):
             """
         )
 
-        output = self.run(self._executable, "-", input_=script)
+        output = self.run_python_script(script)
 
         return [Tag(*t) for t in json.loads(output)]
 
@@ -1424,7 +1437,7 @@ class VirtualEnv(Env):
         return Version.parse(m.group(1))
 
     def get_paths(self):  # type: () -> Dict[str, str]
-        output = self.run(self._executable, "-", input_=GET_PATHS)
+        output = self.run_python_script(GET_PATHS)
 
         return json.loads(output)
 
@@ -1542,7 +1555,7 @@ class GenericEnv(VirtualEnv):
                 self._pip_executable = pip_executable
 
     def get_paths(self):  # type: () -> Dict[str, str]
-        output = self.run(self._executable, "-", input_=GET_PATHS_FOR_GENERIC_ENVS)
+        output = self.run_python_script(GET_PATHS_FOR_GENERIC_ENVS)
 
         return json.loads(output)
 
